@@ -18,18 +18,14 @@
 #ifndef BOARD_H
 #define BOARD_H
 
+// Qt
 #include <QGraphicsScene>
-#include <KGameRenderer>
-
-#include <QSize>
 #include <QList>
 #include <QQueue>
-#include <QDir>
+#include <QSize>
 
-namespace Phonon
-{
-class MediaObject;
-}
+// KDE
+#include <KGameRenderer>
 
 class Plane;
 class Building;
@@ -39,19 +35,18 @@ class Bomb;
  * This class used to represent the game board. This makes sure all the game objects
  * get moved and redrawn every second. It also checks for any collisions
  */
-class BomberBoard: public QGraphicsScene
+class BomberBoard : public QGraphicsScene
 {
     Q_OBJECT
 
 public:
-
     /**
      * The constructor used to create the board.
      * \param renderer The renderer used to render game objects
      * \param view The graphics view object which this board is bound to
      * \param parent The widget which the board is inserted into
      */
-    explicit BomberBoard(KGameRenderer *renderer, QGraphicsView *view, QObject *parent = nullptr);
+    explicit BomberBoard(KGameRenderer * renderer, QGraphicsView * view, QObject * parent = nullptr);
 
     ~BomberBoard();
 
@@ -59,7 +54,7 @@ public:
      * This is called when the game board is resized
      * \param size The new tile size used on the game board
      */
-    void resize(QSize &size);
+    void resize(QSize & size);
 
     /**
      * This will redraw the game board
@@ -78,31 +73,19 @@ public:
      */
     void setPaused(bool val);
 
-    /**
-     * Used to play a sound
-     * \param name The sound to play
-     */
-    void playSound(const QString &name);
-
-    /**
-     * Used to activate/deactivate sounds while playing
-     * \param val True to turn on the sounds, otherwise false
-     */
-    void setSounds(bool val);
-
     /**
      * This will convert the tile location to actual cords on the board
      * \param pos The cords relative to the tile
      * \return The cords relative to the widget
      */
-    QPoint mapPosition(const QPointF &pos) const;
+    QPoint mapPosition(const QPointF & pos) const;
 
     /**
      * This will convert the widget location to tile locations
      * \param pos The cords relative to the widget
      * \return The cords relative to the tile
      */
-    QPointF unmapPosition(const QPoint &pos) const;
+    QPointF unmapPosition(const QPoint & pos) const;
 
     /**
      * Used to set the plane state to flying and move it to the start position
@@ -114,12 +97,15 @@ public:
      */
     void dropBomb();
 
-signals:
+Q_SIGNALS:
     /**
      * This is emitted when a plane crashes into a building
      */
     void onPlaneCrash();
 
+    void playBombSound();
+    void playCrashSound();
+
     /**
      * This signal is emitted when a bomb hits a building and before it's exploding
      * animation starts
@@ -131,13 +117,13 @@ signals:
      */
     void levelCleared();
 
-public slots:
+public Q_SLOTS:
     /**
      * This is called when the settings change to save the settings
      */
     void settingsChanged();
 
-private slots:
+private Q_SLOTS:
     /**
      * This is called once a second to update and draw all the game objects
      */
@@ -160,7 +146,7 @@ private:
      * \param moveBombToX The x position to move the explosion too
      * \param moveBombToY The y position to move the explosion too
      */
-    void bombHit(Bomb *bomb, qreal moveBombToX, qreal moveBombToY);
+    void bombHit(Bomb * bomb, qreal moveBombToX, qreal moveBombToY);
 
     /**
      * This is used to remove all the current game objects, usually called before
@@ -181,27 +167,23 @@ private:
     /**
      * This is the renderer used to render game objects
      */
-    KGameRenderer *m_renderer;
+    KGameRenderer * m_renderer;
 
     /**
      * This is the size of a tiling block
      */
     QSize m_tileSize;
-    QTimer *m_clock;
-
-    Phonon::MediaObject *m_audioPlayer;
-    bool m_playSounds;
-    QDir m_soundPath;
+    QTimer * m_clock;
 
     /**
      * If their is a bomb currently dropping then it is pointed to by this
      */
-    Bomb *m_bomb;
+    Bomb * m_bomb;
 
     /**
      * This points to the plane object used in the level
      */
-    Plane *m_plane;
+    Plane * m_plane;
 
     /**
      * This contains all the buildings in the current level
@@ -221,7 +203,7 @@ private:
     /**
      * This is the graphics view object which this board is bound.
      */
-    QGraphicsView *m_view;
+    QGraphicsView * m_view;
 };
 
 #endif
